import sys
import traceback
import webbrowser

def searchErr(file):
    try:
        code = compile(open(file).read(), file, 'exec')
        exec(code)
    except Exception:
        full_error_msg = traceback.format_exc()
        split_msg = full_error_msg.split("\n")
        del split_msg[1]
        del split_msg[1]
        print('\n'.join(split_msg))
        err = split_msg[-2]
        err.replace(' ', '+')
        webbrowser.open_new_tab("https://www.google.com/search?q="+err)


from setuptools import setup

from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(name='pySearchErr',
      version='0.2.0',
      description='Detects Python3 exception and searches for the error on Google automatically',
      long_description=long_description,
      long_description_content_type='text/markdown',
      url='https://github.com/JING1201/SwampHacks2020',
      author='jlionwg',
      license='MIT',
      packages=['pySearchErr'],
      scripts=['bin/pySearchErr'],
      zip_safe=False)